#
# spec file for package python-django-grappelli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-grappelli
Version:        4.0.1
Release:        2.2
Summary:        A skin for the Django Admin-Interface
License:        BSD-2-Clause AND LGPL-2.1-or-later
URL:            https://github.com/sehmaschine/django-grappelli
Source:         https://github.com/sehmaschine/django-grappelli/archive/%{version}.tar.gz#/django-grappelli-%{version}.tar.gz
BuildRequires:  %{python_module Django >= 2.2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 5.0}
BuildRequires:  %{python_module pytest-django >= 3.6}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.2
BuildArch:      noarch
%python_subpackages

%description
A jazzy skin for the Django Admin-Interface.

%prep
%autosetup -p1 -n django-grappelli-%{version}

find grappelli/templates/ -type f | xargs chmod -R a-x
find grappelli/static/grappelli/stylesheets/ -type f | xargs chmod -R a-x

%build
%pyproject_wheel

%install
%pyproject_install
%{python_expand rm -r %{buildroot}%{$python_sitelib}/grappelli/tests/
%fdupes %{buildroot}%{$python_sitelib}
}

%check
PYTHONPATH=.
export PYTHONDONTWRITEBYTECODE=1
export DJANGO_SETTINGS_MODULE=test_project.settings
%pytest

%files %{python_files}
%license LICENSE
%doc AUTHORS README.rst
%{python_sitelib}/grappelli
%{python_sitelib}/django_grappelli-%{version}.dist-info

%changelog
* Thu Sep  5 2024 Steve Kowalik <steven.kowalik@suse.com>
- Drop unneeded BuildRequires on pylib.
* Fri May  3 2024 Dirk Müller <dmueller@suse.com>
- update to 4.0.1:
  * Compatibility with Django 5.x
  * Adjusted checkbox (and related radio) styles.
  * Added block submit-row to allow extending the submit line.
  * Removed length_is template filter in favour of length.
  * Fixed: breadcrumbs block.
  * Fixed: logout link (POST instead of GET).
  * Fixed: First non-checkbox column in changelist aligned
    center.
  * Fixed: Delete a warning with Python 3.12.
  * Fixed: Translation string of Cancel button with Form.
  * Fixed: Trigger change event in dismissRelatedLookupPopup.
* Wed Mar 13 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file
* Tue Mar 12 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.8:
  * Fixed collectstatic with ManifestStaticFilesStorage.
  * Fixed removing text with DateTime Shortcuts.
  * Fixed autocomplete inlines with new rows.
  * Improved CSS (removed compass).
* Mon Sep 18 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.7:
  * Updated jQueryUI to 1.13.2.
  * Added readthedocs yaml file.
* Sun May  7 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.6:
  * Fixed incorrect label of option returned by RelatedLookup
    view.
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.5:
  * Removed package.json from jquery-ui.
  * Fixed change_list_filter_confirm peoduces wrong url
    parameters.
  * Fixed change_list_filter_confirm is using
    admin_list.admin_list_filter instead of
    grp_tags.admin_list_filter.
  * Added default for dummy template with dahboard (because of
    django-compressor offline compression).
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.4:
  * Fixed race condition issue with Grunt.
  * Fixed readonly ID field.
  * Fixed utf-8 characters in TinyMCE staticfiles.
  * Fixed changelist actions.
* Thu Jan 13 2022 John Vandenberg <jayvdb@gmail.com>
- Remove tests from runtime package
- Update to v3.0.1
  * Add compatibility with Django 4.0.
- from v2.15.4
  * Removed obsolete ifnotequal tag with search template.
  * Removed duplicate Django Javascripts from Grappelli.
  * Improved and styled Django autocompletes.
- from v2.15.3
  * Added missing files from previous release.
- from v2.15.2
  * Fixed ellipsis with pagination.
  * Fixed redirect with switch.
  * Fixed constance template.
  * Fixed Django Autocompletes.
- from v2.15.1
  * First release of Grappelli which is compatible with Django 3.2.
- from v2.14.4
  * Fixed: Redirect with switch user.
  * Improved: Remove extra filtering in AutocompleteLookup.
  * Improved: Added import statement with URLs for quickstart docs.
  * Improved: Added additional blocks with inlines to allow override.
- from v2.14.3
  * Fixed: Compatibility with Django 3.1.
  * Fixed: Docs about adding Grappelli documentation URLS.
* Mon Aug 31 2020 Marketa Calabkova <mcalabkova@suse.com>
- Launch tests
* Tue Jun  9 2020 Ondřej Súkup <mimi.vx@gmail.com>
- Update to 2.14.2
  * Fixed: Django version (3.0) with docs and quickstart.
  * Fixed: Dashboard with metaclass.
  * Fixed: Missing variable in RelatedObjectLookups.
  * Fixed: Sortables with tuples when using StackedInlines.
  * Improved: Removed six dependency.
  * Improved: Changed bodyclass in order to allow adding more attributes.
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.14.1:
  * First release of Grappelli which is compatible with Django 3.0.
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.13.3:
  * Fixed: Horizontal scrolling.
  * Fixed: Changelist with custom filters.
  * Fixed: Form select icons (Chrome).
  * Fixed: added Django autocomplete JS files.
  * Fixed: added minified jQuery 3.3.1 file.
  * Fixed: added request to formfield_for_dbfield.
  * Fixed: use safe label with autocompletes.
  * Improved: added separate file for documentation URLs.
  * Improved: removed Python 2 support.
  * Improved: CSS footer and submit-row fixes.
  * Improved: CSS field width with inline tabular.
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.13.1:
  * First release of Grappelli which is compatible with Django 2.2.
* Mon May  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.12.3:
  * Improved: use get_username with object history.
  * Improved: trigger change event in dismissChangeRelatedObjectPopup.
  * Improved: honor cl.show_full_result_count with pagination.
  * Fixed: using a div.grp-related-widget to wrap all possible widgets.
* Wed Feb 27 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.12.2:
  * New: edit and delete links with related objects.
  * New: Templates in order to allow integration with django-import-export.
  * Improved: Use admin site_header as title (if given and not default).
  * Improved: compass/sass setup.
  * Fixed: view permissions.
  * Fixed: last inline form with non-editable inlines.
* Tue Dec 11 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.12.1:
  * Many changes to enumerate
  * Support for new djangos
- Switch to singlespec
- Run tests
* Sun May  3 2015 benoit.monin@gmx.fr
- update to version 2.6.4:
  * Fixed: Prepopulated fields with inlines.
  * Fixed: Hide row if only hidden fields are given.
  * Fixed: Background with pulldown handler.
  * Fixed: Python to JSON Serialization with autocompletes with
    non-automatic id.
  * Fixed: Handled LookupError in RelatedLookup view with wrong
    app_label/model_name.
  * Fixed: Add link with changelist.
  * Fixed: Error when constance needs a hidden field.
  * Fixed: ID generation in the dashboard template app_list.html.
  * Fixed: Breadcrumb links in the template change_password.html.
  * Fixed: Use get_username to retrieve username, support custom
    user models.
  * Fixed: Sorting with dashboard when verbose_name_plural is not
    given.
  * Fixed: Removed site dependencies for admin doc views.
- additional changes from version 2.6.3:
  * New: Triggering change when input is changed in autocomplete.
  * New: Blocks header, navigation, user-tools and
    context-navigation with base.html.
  * Fixed: Scrollbars with M2M (with some browsers).
  * Improved: Removed note about order of STATICFILES_FINDERS from
    the docs.
- additional changes from version 2.6.2:
  * Fixed: Tests with custom User model.
  * Fixed: Removed _to_field from generic lookups.
  * Fixed: Used user.pk instead of user.id with dashboard module.
  * Fixed: Unique appconfig with grappelli.dashboard.
  * Improved: Grappelli admin title is used for site title as well
    (if given).
  * Improved: Added block branding to base.html.
- additional changes from version 2.6.1:
  * First release of Grappelli which is compatible with Django 1.7
- update project URL
- remove executable bit from text files
- delete sed call to fix end of line: not needed anymore
* Fri Sep 27 2013 p.drouand@gmail.com
- Update to version 2.4.6
  + Add compatibility with Django 1.4/1.5
- Use download url as source
* Fri Feb 22 2013 alexandre@exatati.com.br
- Update to 2.4.4:
  * New: Added Czech translation for TinyMCE.
  * Fixed: set correct case-sensitive dependency for Django in
    setup.py.
  * Fixed: Make setup.py work with Python 3.
  * Fixed: Breadcrumbs with delete_confirmation.
  * Fixed: Showing help-text with empty FK autocompletes.
  * Fixed: Custom USERNAME_FIELD names for Django 1.5.
  * Fixed: Updated grappelli/urls to support Django 1.5.
  * Fixed: Added has_usable_password.
  * Fixed: Distinct results with Autocompletes.
  * Fixed: Fix RelatedLookup when called with empty string as
    object_id.
  * Fixed: 2 clicks to remove items with m2m–autocompletes.
  * Fixed: Error with adding values to hidden–fields with
    autocomplets (after using the pop up window).
  * Fixed: Autocomplete generic lookups when object_id is not an
    integer field.
  * Improved: App titles are now translatable with the dashboards
    app list.
  * Improved: Rewrites views into class-based views.
  * Improved: Better messages with autocompletes and no results.
  * Improved: Removed Django as a requirement with the setup file.
  * Improved: Replaced p.grp-readonly with div.grp-readonly (in
    order to show contents with mark_safe).
* Fri Nov  9 2012 alexandre@exatati.com.br
- Update to 2.4.3:
  * Fixed: i18n of the Save-Button.
  * Fixed: ``related_label`` used for autocomplete list.
  * Fixed: help_text with related–lookups and autocomplete lookups
    (help_text with M2M is not possible because of a django–bug).
  * Fixed: Bug with model does not exist and m2m lookups.
  * Fixed: Calendar button with Chrome and zooming.
  * Improved: Error messages on Change–List are now below form
    fields (not above).
  * Improved: Design of the Login screen.
  * Improved: Cloning inlines now works with django-autocomplete-light.
  * Added: Password reset (on login page).
  * New: New Login screen.
  * New: Support for Django 1.5.
* Wed Sep 19 2012 alexandre@exatati.com.br
- Update to 2.4.2:
  * Fixed: Bug with change-permissions on ModelList
    (grappelli.dashboard).
  * Added: Alternative ChangeList Template (with filters on the
    right hand side).
  * Added: Alternative ChangeList Filter Template (displaying filters
    as list/options).
- Aditional changes from 2.4.1:
  * Fixed: Footer buttons in change_form.html do not flow correctly
    when screen width is reduced.
  * Fixed: Breadcrumbs of delete_selected_confirmation.
  * Fixed: Added titles for page-tools (open/close).
  * Fixed: Margins and capfirst for filter labels.
  * Fixed: Delete persmissions with inlines (stacked and tabular).
  * Fixed: Removed double dots for labels with auth- and
    registration-templates.
  * Fixed: Button with TinyMCE AdvLink.
  * Fixed: Timepicker closes with ESC.
  * Fixed: Window width with popups.
  * Added: Compass experimental svg support (for IE9).
  * Added: Reset actions select box with javascript.
  * Added setting ``AUTOCOMPLETE_LIMIT``.
  * Improved: sortables with django file uploads.
  * Improved: HTML is now allowed for object representation with
    related-lookups.
  * Improved: Documentation with using TinyMCE.
* Fri Jul 20 2012 jfunk@funktronics.ca
- Update to 2.4.0:
  * Compatibility with Django 1.4
  * New: Grappelli namespace (grp-) for css-classes.
  * New: Grappelli namespace (grp.jQuery) for jQuery.
  * New: Compass-based CSS
  * New: Added toggle-all with change-form
  * New: DOM-Documentation
  * New: sortable_excludes
  * New: 2 different Changelists (one with sidebar filters).
  * New: Minified Grappelli Javascripts.
  * New: Added support for django-reversion.
  * Changed: Selectors with Inlines in order to update the sortable-field (now also works with File-Fields)
  * Changed: Updated jQuery to 1.7.2
- Add missing LICENSE and README files
- Use fdupes
* Tue Apr  3 2012 alexandre@exatati.com.br
- Update to 2.3.8:
  * TinyMCE Update (3.5b2)
* Mon Feb 27 2012 cfarrell@suse.com
- license update: BSD-2-Clause and LGPL-2.1+
  tinymce is LGPL-2.1+ licensed
* Mon Feb 13 2012 alexandre@exatati.com.br
- Update to 2.3.7:
  * Fixed compatibility issue with Python 2.5.
  * Fixed some translations.
* Fri Feb 10 2012 alexandre@exatati.com.br
- Update to 2.3.6:
  * Fixed issue where autocomplete/related settings could not use tuples.
  * Fixed a bug with toggle all actions on the changlist
  * Fixed a bug with adding dynamic-forms to tabular and stacked inlines
    (which caused the remove-handler to throw an error)
  * Autocompletes: Only do a lookup with generics, if content-type
    is defined.
  * Support for new URL tags, see https://docs.djangoproject.com/en/dev/releases/1.3/#changes-to-url-and-ssi.
  * Fixed a bug with m2m-lookups (return obj.pk instead of obj.id).
  * Fixed a bug with very long filters (hidden behind the footer).
  * Added german and french UI-datepicker.
  * Added support for non-integer IDs with generic relations.
  * Added pre_content and post_content to dashboard.
  * Added inline_classes.
  * Added polish translation for TinyMCE and grappelli contextmenu.
  * Removed ``title_url`` from dashboard-docs (it hasn´t been used
    anyway so far).
* Tue Oct 11 2011 alexandre@exatati.com.br
- Update to 2.3.5:
  - Improved performance for autocomplete lookups (staticmethod
    autocomplete_search_fields is required from now on)
* Thu Sep  8 2011 alexandre@exatati.com.br
- Update to 2.3.4:
  * Moved grappelli to GitHub
  * Fixed a bug with the View on Site link (tabular/stacked inlines)
  * Added a placeholder for inline sortables
  * Fixed a bug with collapse all (stacked inlines)
  * Added autocompletes
  * Updated jQuery (to 1.6.2) and jQueryUI (to 1.8.15)
  * Added error-messages to the login form
  * Fixed a bug with hidden-fields in tabular-inlines
* Wed Jun 29 2011 alexandre@exatati.com.br
- Update to 2.3.3:
  - Documentation update
  - FileBrowser-related updates
  - Fixed a bug with delete-confirmation
  - Removed the js for adding nowrap-class (fixed with the latest
    django-version)
  - Stable sorting for dashboard.ModelList
  - Added collapse-handler to h4 for stacked-inlines
  - Help-text is now available with tabular-inlines
  - Fixed some translation-issues
  - Fixed loading-issues with Chrome
  - Reversed asc-/desc-icons
  - Updated TinyMCE to 3.4.2
* Tue Apr 19 2011 alexandre@exatati.com.br
- Update to 2.3.2 to match Django 1.3;
- Regenerate spec file with py2pack.
* Wed Nov  3 2010 alexandre@exatati.com.br
- Update to 2.2.
* Wed Sep  8 2010 alexandre@exatati.com.br
- Update to 2.1;
- Bzip2 source file;
- Spec file cleaned with spec-cleaner.
* Mon Jan 25 2010 alexandre@exatati.com.br
- Update to 2.0.
* Tue Sep 15 2009 alexandre@exatati.com.br
- Initial package (0.1) for openSUSE.
